document.addEventListener("DOMContentLoaded", function () {
  loadPages(); // تحميل قائمة الصفحات عند فتح الصفحة
  loadScheduledPosts(); // تحميل المنشورات المجدولة
});

// 🔹 تحميل الصفحات المتاحة للنشر
function loadPages() {
  fetch("/get_pages")
    .then((response) => response.json())
    .then((data) => {
      let pagesContainer = document.getElementById("pages-container");
      pagesContainer.innerHTML = ""; // مسح أي بيانات قديمة

      if (data.pages) {
        data.pages.forEach((page) => {
          let btn = document.createElement("button");
          btn.type = "button";
          btn.classList.add("btn", "btn-outline-primary", "btn-page");
          btn.textContent = page.name;
          btn.dataset.pageId = page.page_id;
          btn.onclick = function () {
            this.classList.toggle("selected");
          };

          pagesContainer.appendChild(btn);
        });
      } else {
        pagesContainer.innerHTML =
          "<p class='text-danger'>⚠️ لا توجد صفحات متاحة.</p>";
      }
    })
    .catch((error) => console.error("❌ خطأ في جلب قائمة الصفحات:", error));
}

// 🔹 تحديد أو إلغاء تحديد جميع الصفحات
function toggleAllPages() {
  let buttons = document.querySelectorAll(".btn-page");
  let allSelected = [...buttons].every((btn) =>
    btn.classList.contains("selected")
  );
  buttons.forEach((btn) => btn.classList.toggle("selected", !allSelected));
}

// 🔹 تحميل المنشورات المجدولة من السيرفر
function loadScheduledPosts() {
  fetch("/get_scheduled_posts")
    .then((response) => response.json())
    .then((data) => {
      let scheduledPostsContainer = document.getElementById("scheduled-posts");
      scheduledPostsContainer.innerHTML = "";

      if (data.length === 0) {
        scheduledPostsContainer.innerHTML =
          "<tr><td colspan='5' class='text-muted'>⚠️ لا توجد منشورات مجدولة</td></tr>";
        return;
      }

      data.forEach((post) => {
        let row = document.createElement("tr");
        row.innerHTML = `
                    <td><input type="checkbox" class="post-checkbox" value="${
                      post.id
                    }"></td>
                    <td>${post.message}</td>
                    <td>${post.pages.join(
                      ", "
                    )}</td> <!-- عرض أسماء الصفحات هنا -->
                    <td>${new Date(
                      post.schedule_time * 1000
                    ).toLocaleString()}</td>
                    <td>
                        <button class="btn btn-danger btn-sm" onclick="deletePost(${
                          post.id
                        })">🗑 حذف</button>
                    </td>
                `;
        scheduledPostsContainer.appendChild(row);
      });
    })
    .catch((error) =>
      console.error("❌ خطأ في جلب المنشورات المجدولة:", error)
    );
}
// 🔹 تحديد أو إلغاء تحديد جميع المنشورات المجدولة
function toggleSelectAll() {
  let checkboxes = document.querySelectorAll(".post-checkbox");
  let selectAllCheckbox = document.getElementById("select-all");
  checkboxes.forEach(
    (checkbox) => (checkbox.checked = selectAllCheckbox.checked)
  );
}

// 🔹 حذف منشور معين عند النقر على زر الحذف
function deletePost(postId) {
  if (!confirm("هل أنت متأكد أنك تريد حذف هذا المنشور؟")) return;

  fetch("/delete_post", {
    method: "POST",
    body: new URLSearchParams({ post_id: postId }),
    headers: { "Content-Type": "application/x-www-form-urlencoded" },
  })
    .then((response) => response.json())
    .then((data) => {
      alert(data.message);
      loadScheduledPosts(); // إعادة تحميل القائمة بعد الحذف
    })
    .catch((error) => console.error("❌ خطأ أثناء حذف المنشور:", error));
}

// 🔹 حذف جميع المنشورات المحددة دفعة واحدة
function deleteSelectedPosts() {
  let selectedPosts = [
    ...document.querySelectorAll(".post-checkbox:checked"),
  ].map((cb) => cb.value);
  if (selectedPosts.length === 0) {
    alert("يرجى تحديد منشور واحد على الأقل لحذفه!");
    return;
  }

  if (!confirm(`هل أنت متأكد أنك تريد حذف ${selectedPosts.length} منشورات؟`))
    return;

  fetch("/delete_multiple_posts", {
    method: "POST",
    body: new URLSearchParams({
      post_ids: JSON.stringify(selectedPosts),
    }),
    headers: { "Content-Type": "application/x-www-form-urlencoded" },
  })
    .then((response) => response.json())
    .then((data) => {
      alert(data.message);
      loadScheduledPosts(); // تحديث القائمة بعد الحذف
    })
    .catch((error) => console.error("❌ خطأ أثناء حذف المنشورات:", error));
}

// 🔹 إرسال البيانات إلى السيرفر للنشر الفوري أو الجدولة
function submitForm(actionType) {
  const formData = new FormData(document.getElementById("postForm"));
  formData.append("action", actionType);

  let selectedPages = [...document.querySelectorAll(".btn-page.selected")].map(
    (btn) => btn.dataset.pageId
  );
  if (selectedPages.length === 0) {
    alert("يرجى اختيار صفحة واحدة على الأقل!");
    return;
  }
  selectedPages.forEach((pageId) => formData.append("pages", pageId));

  let scheduleInterval = document.getElementById("schedule_interval").value;
  formData.append("schedule_interval", scheduleInterval);

  document.getElementById("loading").style.display = "block";
  document.getElementById("message-box").style.display = "none";

  fetch("/post", {
    method: "POST",
    body: formData,
  })
    .then((response) => response.json())
    .then((data) => {
      document.getElementById("loading").style.display = "none";
      let messageBox = document.getElementById("message-box");

      if (data.status === "scheduled") {
        messageBox.textContent = "✅ تمت جدولة المنشور بنجاح!";
        messageBox.classList.add("alert", "alert-success");
        loadScheduledPosts();
      } else if (data.status === "error") {
        messageBox.textContent = "❌ حدث خطأ أثناء العملية!";
        messageBox.classList.add("alert", "alert-danger");
      } else {
        messageBox.textContent = "✅ تم نشر المنشور بنجاح!";
        messageBox.classList.add("alert", "alert-success");
      }
      messageBox.style.display = "block";
    })
    .catch((error) => {
      document.getElementById("loading").style.display = "none";
      let messageBox = document.getElementById("message-box");
      messageBox.textContent = "❌ خطأ في الاتصال بالخادم!";
      messageBox.classList.add("alert", "alert-danger");
      messageBox.style.display = "block";
    });
}

// 🔹 ضبط الوقت الافتراضي لحقل "موعد الجدولة" ليكون الوقت الحالي
document.addEventListener("DOMContentLoaded", function () {
  let now = new Date();

  // الحصول على التاريخ والوقت المحلي بتنسيق مناسب
  let currentDateTime = now.toLocaleString("sv-SE").slice(0, 16); // تنسيق لتحديد الوقت المحلي
  document.getElementById("schedule_time").value = currentDateTime;
});
